@@ -1,5 +1,7 @@
 """This module contains the state model of the battery."""
-from pysimmods.model.state import ModelState
+from typing import Any, Dict
+
+from ...model.state import ModelState
 
 
 class BatteryState(ModelState):
@@ -32,9 +34,9 @@ class BatteryState(ModelState):
 
     """
 
-    def __init__(self, inits):
+    def __init__(self, inits: Dict[str, Any]):
         super().__init__(inits)
 
-        self.soc_percent = inits["soc_percent"]
-        self.eta_percent = None
-        self._energy_kwh = None
+        self.soc_percent: float = inits["soc_percent"]
+        self.eta_percent: float = None
+        self._energy_kwh: float = None
