@@ -122,15 +122,11 @@ class BiogasPlant(Generator):
     def _check_inputs(self, nstate):
         if self.inputs.p_set_kw is None:
             if self.inputs.now_dt is not None:
-                default_val = self.config.default_schedule[
+                nstate.p_kw = self.config.default_p_schedule[
                     self.inputs.now_dt.hour
                 ]
-                if self.config.use_decimal_percent:
-                    default_val *= 0.01
-                self.set_percent(default_val)
-                nstate.p_kw = self.inputs.p_set_kw
             else:
-                nstate.p_w = 0
+                nstate.p_kw = 0
         else:
             nstate.p_kw = self.inputs.p_set_kw
 
