@@ -1,7 +1,28 @@
 """This module contains the config model for the Biogas plant."""
 
-from pysimmods.model.config import ModelConfig
 import itertools
+from typing import List
+
+from pysimmods.model.config import ModelConfig
+
+DEFAULT_SCHEDULE_1: List[float] = (
+    [0, 0, 0, 0, 10, 10, 10, 10]
+    + [10, 10, 10, 10, 100, 100, 25, 25]
+    + [25, 25, 25, 100, 100, 10, 10, 10]
+)
+
+DEFAULT_SCHEDULE_2: List[float] = (
+    [25, 25, 25, 25, 25, 25, 25, 25]
+    + [25, 25, 25, 25, 100, 100, 50, 50]
+    + [50, 50, 50, 100, 100, 25, 25, 25]
+)
+
+
+DEFAULT_SCHEDULE_3: List[float] = (
+    [0, 0, 0, 0, 10, 10, 10, 10]
+    + [10, 10, 10, 10, 100, 100, 50, 50]
+    + [50, 50, 50, 100, 100, 10, 10, 10]
+)
 
 
 class BiogasConfig(ModelConfig):
@@ -68,29 +89,18 @@ class BiogasConfig(ModelConfig):
         self.p_max_kw = max(self.pn_stages_kw)
         self.p_min_kw = min(self.pn_stages_kw)
 
-        self.default_schedule = [
-            50,
-            50,
-            50,
-            50,
-            50,
-            100,
-            100,
-            100,
-            100,
-            50,
-            50,
-            50,
-            100,
-            100,
-            50,
-            50,
-            50,
-            100,
-            100,
-            100,
-            100,
-            50,
-            50,
-            50,
+        if self.num_chps == 1:
+            default_schedule = DEFAULT_SCHEDULE_1
+        elif self.num_chps == 2:
+            default_schedule = DEFAULT_SCHEDULE_2
+        else:
+            default_schedule = DEFAULT_SCHEDULE_3
+
+        self.default_p_schedule: List[float] = [
+            self.p_min_kw + dv * self.p_max_kw / 100 for dv in default_schedule
         ]
+        self.default_q_schedule: List[float] = [0.0] * 24
+
+        self.default_p_schedule = params.get(
+            "default_schedule", self.default_p_schedule
+        )
