@@ -1,8 +1,5 @@
 """This module contains the state model of the chp."""
-from datetime import datetime
-
 from pysimmods.model.state import ModelState
-from pysimmods.util.dateformat import GER
 
 
 class CHPLPGState(ModelState):
