@@ -13,7 +13,9 @@ class CHPLPGSystemConfig(ModelConfig):
 
         self.house = HeatDemandConfig(params["household"])
         self.chp = CHPLPGConfig(params["chp"])
-
+        self.e_th_demand_sign = 1.0
+        if params.get("flip_e_th_demand_sign", False):
+            self.e_th_demand_sign = -1.0
         self.default_schedule = self.chp.default_schedule
 
     @property
