@@ -95,7 +95,8 @@ class PVConfig(ModelConfig):
         self.p_max_kw = self.eta_percent / 100 * self.a_m2
         self.p_min_kw = 0
         self.max_step_size = 300
-        self.default_schedule = None
+        self.default_p_schedule = None
+        self.default_q_schedule = None
 
     # @property
     # def p_min_kw(self):
