@@ -1,8 +1,5 @@
 """This module contains the input model for PV plant."""
-from datetime import datetime
-
 from pysimmods.model.inputs import ModelInputs
-from pysimmods.util.dateformat import GER
 
 
 class PVInputs(ModelInputs):
