@@ -67,4 +67,4 @@ class PVPlantSystem(QGenerator):
         self.state.q_kvar = self.inverter.state.q_kvar
 
     def set_q_kvar(self, q_kvar: float) -> None:
-        return self.inverter.set_q_kvar(q_kvar)
+        self.inputs.q_set_kvar = q_kvar
