@@ -33,10 +33,14 @@ class ModelConfig:
     use_decimal_percent: bool
         If *True* decimal percentage [0, 1.0] is used, otherwise normal
         percentage [0, 100] ist used.
-    default_schedule: List[float]
-        A *list* containing a default schedule with percentage
-        power for each hour of the day (i.e., len(default_schedule) ==
-        24). This is used if no other *p* or *q* input is provided.
+    default_p_schedule: List[float]
+        A *list* containing a default schedule for active power for
+        each hour of the day (i.e., len(default_schedule) == 24). This
+        is used if no other *p* input is provided.
+    default_q_schedule: List[float]
+        A *list* containing a default schedule for reactive power for
+        each hour of the day (i.e., len(default_schedule) == 24). This
+        is used if no other *q* input is provided.
     p_min_kw: float
         The minimum nominal active power output of the model.
     p_max_kw: float
@@ -68,7 +72,8 @@ class ModelConfig:
             self.lsign = 1
 
         self.use_decimal_percent = params.get("use_decimal_percent", False)
-        self.default_schedule = params.get("default_schedule", [50] * 24)
+        self.default_p_schedule = params.get("default_p_schedule", [0.0] * 24)
+        self.default_q_schedule = params.get("default_q_schedule", [0.0] * 24)
 
         self.p_min_kw: float
         self.p_max_kw: float
