@@ -15,20 +15,10 @@ class Consumer(Model):
     """
 
     def set_p_kw(self, p_kw: float) -> None:
-        p_min = self.get_pn_min_kw()
-        p_max = self.get_pn_max_kw()
-
-        if p_kw * self.config.lsign > 0:
-            # Consuming power
-            p_kw = abs(p_kw)
-            if p_kw < p_min:
-                # Better turn off than to consume too much power
-                self.inputs.p_set_kw = 0
-            else:
-                self.inputs.p_set_kw = min(p_max, p_kw)
+        if p_kw is not None:
+            self.inputs.p_set_kw = abs(p_kw)
         else:
-            # Can't generate power
-            self.inputs.p_set_kw = 0
+            self.inputs.p_set_kw = None
 
     def get_p_kw(self) -> float:
         return self.state.p_kw * self.config.lsign
