@@ -46,7 +46,13 @@ META = {
         "CHP": {
             "public": True,
             "params": ["params", "inits"],
-            "attrs": ["day_avg_t_air_deg_celsius", "p_th_mw"] + _SHARED_ATTRS,
+            "attrs": [
+                "day_avg_t_air_deg_celsius",
+                "p_th_mw",
+                "e_th_demand_set_kwh",
+                "e_th_demand_kwh",
+            ]
+            + _SHARED_ATTRS,
         },
         "HVAC": {
             "public": True,
