@@ -5,8 +5,8 @@ import pandas as pd
 from midas.util.upgrade_module import UpgradeModule
 from pysimmods.buffer.batterysim.presets import battery_preset
 from pysimmods.consumer.hvacsim.presets import hvac_preset
-from pysimmods.generator.biogassim.presets import biogas_presets
-from pysimmods.generator.chplpgsystemsim.presets import chp_presets
+from pysimmods.generator.biogassim.presets import biogas_preset
+from pysimmods.generator.chplpgsystemsim.presets import chp_preset
 from pysimmods.generator.dieselsim.presets import diesel_presets
 from pysimmods.generator.pvsystemsim.presets import pv_preset
 
@@ -552,12 +552,12 @@ def get_presets(model, p_peak_mw, **kwargs):
     elif model == "HVAC":
         return hvac_preset(pn_max_kw=p_peak_mw * 1e3, **kwargs)
     elif model == "CHP":
-        return chp_presets(p_kw=p_peak_mw * 1e3, **kwargs)
+        return chp_preset(p_kw=p_peak_mw * 1e3, **kwargs)
     elif model == "BAT":
         return battery_preset(pn_max_kw=p_peak_mw * 1e3)
     elif model == "DIESEL":
         return diesel_presets(p_max_kw=p_peak_mw * 1e3)
     elif model == "Biogas":
-        return biogas_presets(pn_max_kw=p_peak_mw * 1e3)
+        return biogas_preset(pn_max_kw=p_peak_mw * 1e3)
     else:
         raise ValueError(f"Model {model} is unknown.")
