@@ -2,6 +2,7 @@
 of the pysimmods package.
 
 """
+import json
 import logging
 import pprint
 from datetime import datetime, timedelta, timezone
@@ -129,11 +130,12 @@ class PysimmodsSimulator(mosaik_api.Simulator):
             The next step this simulator wants to be stepped.
 
         """
-        LOG.debug(
-            "At step %d: Received inputs: %s.",
-            time,
-            pprint.pformat(inputs),
-        )
+        if not self.key_value_logs:
+            LOG.debug(
+                "At step %d: Received inputs: %s.",
+                time,
+                pprint.pformat(inputs),
+            )
 
         self._set_default_inputs()
 
@@ -187,7 +189,7 @@ class PysimmodsSimulator(mosaik_api.Simulator):
                 log_msg[attr] = value
 
             if self.key_value_logs:
-                LOG.info(log_msg)
+                LOG.info(json.dumps(log_msg))
 
         if not self.key_value_logs:
             LOG.debug("Gathered outputs: %s.", pprint.pformat(data))
