@@ -1,5 +1,6 @@
 """This module contains the flexibility model."""
 from datetime import datetime, timedelta
+from typing import Optional
 
 import numpy as np
 import pandas as pd
@@ -17,11 +18,18 @@ class FlexibilityModel(ForecastModel):
         model,
         unit="kw",
         priorize_setpoint=False,
+        step_size: Optional[int] = None,
+        now_dt: Optional[datetime] = None,
         forecast_horizon_hours=1,
         seed=None,
     ):
         super().__init__(
-            model, unit, priorize_setpoint, forecast_horizon_hours
+            model,
+            unit,
+            priorize_setpoint,
+            step_size,
+            now_dt,
+            forecast_horizon_hours,
         )
 
         if seed is not None:
