@@ -1,4 +1,6 @@
 """This module contains the config model for the inverter."""
+from typing import Any, Dict
+
 from pysimmods.model.config import ModelConfig
 from pysimmods.model.qgenerator import QControl
 
@@ -30,7 +32,7 @@ class InverterConfig(ModelConfig):
 
     """
 
-    def __init__(self, params):
+    def __init__(self, params: Dict[str, Any]):
         super().__init__(params)
 
         self.s_max_kva = params["sn_kva"]
@@ -41,6 +43,8 @@ class InverterConfig(ModelConfig):
             "pq_set",
             "qp_set",
         ]
-        self.q_control = QControl[params.get("q_control", "p_set").upper()]
-        self.cos_phi = params.get("cos_phi", 0.9)
+        self.q_control = QControl[
+            params.get("q_control", "prioritize_p").upper()
+        ]
+        self.cos_phi = params.get("cos_phi", 0.95)
         self.inverter_mode = params.get("inverter_mode", "capacitive")
